@@ -7,7 +7,8 @@ from .param import Param
 from .parameter_map import ParameterMap
 from .initializer import Initializer
 from .user_signature import UserSignature
-from .user_proxy import UserProxy
+from .request_proxy import RequestProxy
+from .sdk_config import SDKConfig
 from . import contact_roles
 from . import modules
 from . import attachments
