@@ -1,24 +1,20 @@
-
 try:
-
     from zcrmsdk.src.com.zoho.crm.api.dc.data_center import DataCenter
-
 except Exception as e:
-
     from .data_center import DataCenter
 
 
 class AUDataCenter(DataCenter):
 
     """
-    This class representing the Australian country Zoho CRM and Accounts URL. It is used to denote the domain of the user.
+    This class represents the properties of Zoho CRM in AU Domain.
     """
 
     @classmethod
     def PRODUCTION(cls):
 
         """
-        This Environment class instance represents the Australian country's Zoho CRM production environment.
+        This method represents the Zoho CRM Production environment in AU domain
         :return: A Environment class instance.
         """
 
@@ -28,7 +24,7 @@ class AUDataCenter(DataCenter):
     def SANDBOX(cls):
 
         """
-        This Environment class instance represents the Australian country's Zoho CRM sandbox environment.
+        This method represents the Zoho CRM Sandbox environment in AU domain
         :return: A Environment class instance.
         """
 
@@ -38,25 +34,14 @@ class AUDataCenter(DataCenter):
     def DEVELOPER(cls):
 
         """
-        This Environment class instance represents the Australian country's Zoho CRM developer environment.
+        This method represents the Zoho CRM Developer environment in AU domain
         :return: A Environment class instance.
         """
 
         return DataCenter.Environment("https://developer.zohoapis.com.au", cls(). get_iam_url(), cls().get_file_upload_url())
 
     def get_iam_url(self):
-
-        """
-        This method to get accounts URL.
-        :return: A str representing the accounts URL.
-        """
-
         return "https://accounts.zoho.com.au/oauth/v2/token"
 
     def get_file_upload_url(self):
-        """
-        The method to get File Upload URL
-        :return: A str representing the File Upload URL
-        """
-
         return "https://content.zohoapis.com.au"
