@@ -19,7 +19,7 @@ class LineItemProduct(Record):
 		The method to get the product_code
 
 		Returns:
-			string: A string value
+			string: A string representing the product_code
 		"""
 
 		return self.get_key_value('Product_Code')
@@ -42,7 +42,7 @@ class LineItemProduct(Record):
 		The method to get the currency
 
 		Returns:
-			string: A string value
+			string: A string representing the currency
 		"""
 
 		return self.get_key_value('Currency')
@@ -65,7 +65,7 @@ class LineItemProduct(Record):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.get_key_value('name')
