@@ -21,7 +21,7 @@ class LineTax(object):
 		The method to get the percentage
 
 		Returns:
-			float: A float value
+			float: A float representing the percentage
 		"""
 
 		return self.__percentage
@@ -45,7 +45,7 @@ class LineTax(object):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -69,7 +69,7 @@ class LineTax(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -93,7 +93,7 @@ class LineTax(object):
 		The method to get the value
 
 		Returns:
-			float: A float value
+			float: A float representing the value
 		"""
 
 		return self.__value
@@ -120,7 +120,7 @@ class LineTax(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
