@@ -19,15 +19,15 @@ class RecordOperations(object):
 		"""Creates an instance of RecordOperations"""
 		pass
 
-	def get_record(self, param_instance, header_instance, module_api_name, id):
+	def get_record(self, id, module_api_name, param_instance=None, header_instance=None):
 		"""
 		The method to get record
 
 		Parameters:
+			id (int) : An int representing the id
+			module_api_name (string) : A string representing the module_api_name
 			param_instance (ParameterMap) : An instance of ParameterMap
 			header_instance (HeaderMap) : An instance of HeaderMap
-			module_api_name (string) : A string representing the module_api_name
-			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -36,45 +36,45 @@ class RecordOperations(object):
 			SDKException
 		"""
 
+		if not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
+		
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
 		if header_instance is not None and not isinstance(header_instance, HeaderMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
 		
-		if not isinstance(module_api_name, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
-		
-		if not isinstance(id, int):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
-		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
-		handler_instance.param = param_instance
-		handler_instance.header = header_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
+		handler_instance.set_header(header_instance)
 		Utility.get_fields(module_api_name)
-		handler_instance.module_api_name = module_api_name
+		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
 		except Exception:
 			from .response_handler import ResponseHandler
 		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
 
-	def update_record(self, request, module_api_name, id):
+	def update_record(self, id, module_api_name, request):
 		"""
 		The method to update record
 
 		Parameters:
-			request (BodyWrapper) : An instance of BodyWrapper
-			module_api_name (string) : A string representing the module_api_name
 			id (int) : An int representing the id
+			module_api_name (string) : A string representing the module_api_name
+			request (BodyWrapper) : An instance of BodyWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -88,14 +88,14 @@ class RecordOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if request is not None and not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		if not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(id, int):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -103,27 +103,27 @@ class RecordOperations(object):
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
 		Utility.get_fields(module_api_name)
-		handler_instance.module_api_name = module_api_name
+		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def delete_record(self, param_instance, module_api_name, id):
+	def delete_record(self, id, module_api_name, param_instance=None):
 		"""
 		The method to delete record
 
 		Parameters:
-			param_instance (ParameterMap) : An instance of ParameterMap
-			module_api_name (string) : A string representing the module_api_name
 			id (int) : An int representing the id
+			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -132,14 +132,14 @@ class RecordOperations(object):
 			SDKException
 		"""
 
-		if param_instance is not None and not isinstance(param_instance, ParameterMap):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		if not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(id, int):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -147,24 +147,24 @@ class RecordOperations(object):
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.param = param_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def get_records(self, param_instance, header_instance, module_api_name):
+	def get_records(self, module_api_name, param_instance=None, header_instance=None):
 		"""
 		The method to get records
 
 		Parameters:
+			module_api_name (string) : A string representing the module_api_name
 			param_instance (ParameterMap) : An instance of ParameterMap
 			header_instance (HeaderMap) : An instance of HeaderMap
-			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -173,39 +173,39 @@ class RecordOperations(object):
 			SDKException
 		"""
 
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
 		if header_instance is not None and not isinstance(header_instance, HeaderMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
 		
-		if not isinstance(module_api_name, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
-		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
-		handler_instance.param = param_instance
-		handler_instance.header = header_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
+		handler_instance.set_header(header_instance)
 		Utility.get_fields(module_api_name)
-		handler_instance.module_api_name = module_api_name
+		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
 		except Exception:
 			from .response_handler import ResponseHandler
 		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
 
-	def create_records(self, request, module_api_name):
+	def create_records(self, module_api_name, request):
 		"""
 		The method to create records
 
 		Parameters:
-			request (BodyWrapper) : An instance of BodyWrapper
 			module_api_name (string) : A string representing the module_api_name
+			request (BodyWrapper) : An instance of BodyWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -219,37 +219,37 @@ class RecordOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if request is not None and not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
-		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		Utility.get_fields(module_api_name)
-		handler_instance.module_api_name = module_api_name
+		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def update_records(self, request, module_api_name):
+	def update_records(self, module_api_name, request):
 		"""
 		The method to update records
 
 		Parameters:
-			request (BodyWrapper) : An instance of BodyWrapper
 			module_api_name (string) : A string representing the module_api_name
+			request (BodyWrapper) : An instance of BodyWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -263,37 +263,37 @@ class RecordOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if request is not None and not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
-		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		Utility.get_fields(module_api_name)
-		handler_instance.module_api_name = module_api_name
+		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def delete_records(self, param_instance, module_api_name):
+	def delete_records(self, module_api_name, param_instance=None):
 		"""
 		The method to delete records
 
 		Parameters:
-			param_instance (ParameterMap) : An instance of ParameterMap
 			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -302,33 +302,33 @@ class RecordOperations(object):
 			SDKException
 		"""
 
-		if param_instance is not None and not isinstance(param_instance, ParameterMap):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
-		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.param = param_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def upsert_records(self, request, module_api_name):
+	def upsert_records(self, module_api_name, request):
 		"""
 		The method to upsert records
 
 		Parameters:
-			request (BodyWrapper) : An instance of BodyWrapper
 			module_api_name (string) : A string representing the module_api_name
+			request (BodyWrapper) : An instance of BodyWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -342,38 +342,38 @@ class RecordOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if request is not None and not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
-		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/upsert'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_ACTION
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_ACTION)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
 		Utility.get_fields(module_api_name)
-		handler_instance.module_api_name = module_api_name
+		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def get_deleted_records(self, param_instance, header_instance, module_api_name):
+	def get_deleted_records(self, module_api_name, param_instance=None, header_instance=None):
 		"""
 		The method to get deleted records
 
 		Parameters:
+			module_api_name (string) : A string representing the module_api_name
 			param_instance (ParameterMap) : An instance of ParameterMap
 			header_instance (HeaderMap) : An instance of HeaderMap
-			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -382,38 +382,38 @@ class RecordOperations(object):
 			SDKException
 		"""
 
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
 		if header_instance is not None and not isinstance(header_instance, HeaderMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
 		
-		if not isinstance(module_api_name, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
-		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/deleted'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
-		handler_instance.param = param_instance
-		handler_instance.header = header_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
+		handler_instance.set_header(header_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.deleted_records_handler import DeletedRecordsHandler
 		except Exception:
 			from .deleted_records_handler import DeletedRecordsHandler
 		return handler_instance.api_call(DeletedRecordsHandler.__module__, 'application/json')
 
-	def search_records(self, param_instance, module_api_name):
+	def search_records(self, module_api_name, param_instance=None):
 		"""
 		The method to search records
 
 		Parameters:
-			param_instance (ParameterMap) : An instance of ParameterMap
 			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -422,36 +422,36 @@ class RecordOperations(object):
 			SDKException
 		"""
 
-		if param_instance is not None and not isinstance(param_instance, ParameterMap):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
-		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/search'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
-		handler_instance.param = param_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
 		Utility.get_fields(module_api_name)
-		handler_instance.module_api_name = module_api_name
+		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
 		except Exception:
 			from .response_handler import ResponseHandler
 		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
 
-	def convert_lead(self, request, id):
+	def convert_lead(self, id, request):
 		"""
 		The method to convert lead
 
 		Parameters:
-			request (ConvertBodyWrapper) : An instance of ConvertBodyWrapper
 			id (int) : An int representing the id
+			request (ConvertBodyWrapper) : An instance of ConvertBodyWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -465,23 +465,23 @@ class RecordOperations(object):
 		except Exception:
 			from .convert_body_wrapper import ConvertBodyWrapper
 
-		if request is not None and not isinstance(request, ConvertBodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: ConvertBodyWrapper', None, None)
-		
 		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
+		if request is not None and not isinstance(request, ConvertBodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: ConvertBodyWrapper', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/Leads/'
 		api_path = api_path + str(id)
 		api_path = api_path + '/actions/convert'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		Utility.get_fields("Deals")
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.convert_action_handler import ConvertActionHandler
@@ -489,13 +489,13 @@ class RecordOperations(object):
 			from .convert_action_handler import ConvertActionHandler
 		return handler_instance.api_call(ConvertActionHandler.__module__, 'application/json')
 
-	def get_photo(self, module_api_name, id):
+	def get_photo(self, id, module_api_name):
 		"""
 		The method to get photo
 
 		Parameters:
-			module_api_name (string) : A string representing the module_api_name
 			id (int) : An int representing the id
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -504,12 +504,12 @@ class RecordOperations(object):
 			SDKException
 		"""
 
-		if not isinstance(module_api_name, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
-		
 		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/'
@@ -517,23 +517,23 @@ class RecordOperations(object):
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
 		api_path = api_path + '/photo'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.download_handler import DownloadHandler
 		except Exception:
 			from .download_handler import DownloadHandler
 		return handler_instance.api_call(DownloadHandler.__module__, 'application/x-download')
 
-	def upload_photo(self, request, module_api_name, id):
+	def upload_photo(self, id, module_api_name, request):
 		"""
 		The method to upload photo
 
 		Parameters:
-			request (FileBodyWrapper) : An instance of FileBodyWrapper
-			module_api_name (string) : A string representing the module_api_name
 			id (int) : An int representing the id
+			module_api_name (string) : A string representing the module_api_name
+			request (FileBodyWrapper) : An instance of FileBodyWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -547,14 +547,14 @@ class RecordOperations(object):
 		except Exception:
 			from .file_body_wrapper import FileBodyWrapper
 
-		if request is not None and not isinstance(request, FileBodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: FileBodyWrapper', None, None)
+		if not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(id, int):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
+		if request is not None and not isinstance(request, FileBodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: FileBodyWrapper', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -563,25 +563,25 @@ class RecordOperations(object):
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
 		api_path = api_path + '/photo'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.content_type = 'multipart/form-data'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_content_type('multipart/form-data')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.file_handler import FileHandler
 		except Exception:
 			from .file_handler import FileHandler
 		return handler_instance.api_call(FileHandler.__module__, 'application/json')
 
-	def delete_photo(self, module_api_name, id):
+	def delete_photo(self, id, module_api_name):
 		"""
 		The method to delete photo
 
 		Parameters:
-			module_api_name (string) : A string representing the module_api_name
 			id (int) : An int representing the id
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -590,12 +590,12 @@ class RecordOperations(object):
 			SDKException
 		"""
 
-		if not isinstance(module_api_name, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
-		
 		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/'
@@ -603,22 +603,22 @@ class RecordOperations(object):
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
 		api_path = api_path + '/photo'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.file_handler import FileHandler
 		except Exception:
 			from .file_handler import FileHandler
 		return handler_instance.api_call(FileHandler.__module__, 'application/json')
 
-	def mass_update_records(self, request, module_api_name):
+	def mass_update_records(self, module_api_name, request):
 		"""
 		The method to mass update records
 
 		Parameters:
-			request (MassUpdateBodyWrapper) : An instance of MassUpdateBodyWrapper
 			module_api_name (string) : A string representing the module_api_name
+			request (MassUpdateBodyWrapper) : An instance of MassUpdateBodyWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -632,38 +632,38 @@ class RecordOperations(object):
 		except Exception:
 			from .mass_update_body_wrapper import MassUpdateBodyWrapper
 
-		if request is not None and not isinstance(request, MassUpdateBodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: MassUpdateBodyWrapper', None, None)
-		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
+		if request is not None and not isinstance(request, MassUpdateBodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: MassUpdateBodyWrapper', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/actions/mass_update'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		Utility.get_fields(module_api_name)
-		handler_instance.module_api_name = module_api_name
+		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.mass_update_action_handler import MassUpdateActionHandler
 		except Exception:
 			from .mass_update_action_handler import MassUpdateActionHandler
 		return handler_instance.api_call(MassUpdateActionHandler.__module__, 'application/json')
 
-	def get_mass_update_status(self, param_instance, module_api_name):
+	def get_mass_update_status(self, module_api_name, param_instance=None):
 		"""
 		The method to get mass update status
 
 		Parameters:
-			param_instance (ParameterMap) : An instance of ParameterMap
 			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -672,21 +672,21 @@ class RecordOperations(object):
 			SDKException
 		"""
 
-		if param_instance is not None and not isinstance(param_instance, ParameterMap):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
-		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/actions/mass_update'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
-		handler_instance.param = param_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.mass_update_response_handler import MassUpdateResponseHandler
 		except Exception:
