@@ -108,7 +108,7 @@ class Territory(object):
 		The method to get the parent_id
 
 		Returns:
-			string: A string value
+			string: A string representing the parent_id
 		"""
 
 		return self.__parent_id
@@ -161,7 +161,7 @@ class Territory(object):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -214,7 +214,7 @@ class Territory(object):
 		The method to get the description
 
 		Returns:
-			string: A string value
+			string: A string representing the description
 		"""
 
 		return self.__description
@@ -238,7 +238,7 @@ class Territory(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -294,7 +294,7 @@ class Territory(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
