@@ -1,12 +1,10 @@
 try:
     import re
-    import traceback
     from zcrmsdk.src.com.zoho.crm.api.exception.sdk_exception import SDKException
     from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
 
 except Exception:
     import re
-    import traceback
     from zcrmsdk.src.com.zoho.crm.api.exception.sdk_exception import SDKException
     from .util.constants import Constants
 
@@ -28,7 +26,7 @@ class UserSignature(object):
 
         error = {}
 
-        if re.search(Constants.EMAIL_REGEX, email) is None:
+        if re.fullmatch(Constants.EMAIL_REGEX, email) is None:
             error[Constants.FIELD] = Constants.EMAIL
             error[Constants.EXPECTED_TYPE] = Constants.EMAIL
 
