@@ -2,10 +2,12 @@ try:
     from dateutil.tz import tz
     import dateutil.parser
     from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
+    from datetime import date, datetime
 except Exception:
     from dateutil.tz import tz
     import dateutil.parser
     from .constants import Constants
+    from datetime import date, datetime
 
 
 class DataTypeConverter(object):
@@ -36,7 +38,52 @@ class DataTypeConverter(object):
         DataTypeConverter.add_to_map("Double", lambda obj: float(obj), lambda obj: float(obj))
         DataTypeConverter.add_to_map("Date", lambda obj: dateutil.parser.isoparse(obj).date(), lambda obj: obj.isoformat())
         DataTypeConverter.add_to_map("DateTime", lambda obj: dateutil.parser.isoparse(obj).astimezone(tz.tzlocal()), lambda obj: obj.replace(microsecond=0).astimezone(tz.tzlocal()).isoformat())
-        DataTypeConverter.add_to_map("Object", lambda obj: obj, lambda obj: obj)
+        DataTypeConverter.add_to_map("Object", lambda obj: DataTypeConverter.pre_convert_object_data(obj), lambda obj: DataTypeConverter.post_convert_object_data(obj))
+
+    @staticmethod
+    def pre_convert_object_data(obj):
+        return obj
+
+    @staticmethod
+    def post_convert_object_data(obj):
+        if isinstance(obj, list):
+            list_value = []
+            for data in obj:
+                if isinstance(data, date):
+                    list_value.append(DataTypeConverter.post_convert(data, "Date"))
+                elif isinstance(data, datetime):
+                    list_value.append(DataTypeConverter.post_convert(data, "DateTime"))
+                elif isinstance(data, dict):
+                    list_value.append(DataTypeConverter.post_convert_object_data(data))
+                else:
+                    list_value.append(data)
+
+            return list_value
+
+        elif isinstance(obj, dict):
+            dict_value = {}
+            for key, value in obj.items():
+                if isinstance(value, list):
+                    dict_value[key] = DataTypeConverter.post_convert_object_data(value)
+                elif isinstance(value, date):
+                    dict_value[key] = DataTypeConverter.post_convert(value, "Date")
+                elif isinstance(value, datetime):
+                    dict_value[key] = DataTypeConverter.post_convert(value, "DateTime")
+                elif isinstance(value, dict):
+                    dict_value[key] = DataTypeConverter.post_convert_object_data(value)
+                else:
+                    dict_value[key] = value
+
+            return dict_value
+
+        elif isinstance(obj, date):
+            return DataTypeConverter.post_convert(obj, "Date")
+
+        elif isinstance(obj, datetime):
+            return DataTypeConverter.post_convert(obj, "DateTime")
+
+        else:
+            return obj
 
     @staticmethod
     def add_to_map(name, pre_converter, post_converter):
