@@ -2,14 +2,12 @@ try:
     import importlib
     import logging
     import re
-    import traceback
     import json
     from zcrmsdk.src.com.zoho.crm.api.util import Converter, Constants, StreamWrapper
     from zcrmsdk.src.com.zoho.crm.api.exception.sdk_exception import SDKException
 
 except Exception:
     import importlib
-    import traceback
     import logging
     import re
     from .converter import Converter
@@ -58,8 +56,8 @@ class FormDataConverter(Converter):
 
             if (modification is None or modification == 0) and Constants.REQUIRED in member_detail and bool(
                     member_detail[Constants.REQUIRED]):
-                raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR,
-                                   Constants.MANDATORY_KEY_MISSING_ERROR + member_name)
+                raise SDKException(Constants.MANDATORY_VALUE_ERROR,
+                                   Constants.MANDATORY_KEY_ERROR + member_name)
 
             field_value = getattr(request_instance, self.construct_private_member(class_name=class_name, member_name=member_name))
 
