@@ -85,7 +85,7 @@ class JSONConverter(Converter):
             class_member_name = class_member_detail[Constants.NAME]
 
         request_json = {}
-        required_keys, primary_keys, required_in_update_keys = [], [], []
+        required_keys, primary_keys, required_in_update_keys = {}, {}, {}
 
         for member_name, member_detail in class_detail.items():
             if Constants.READ_ONLY in member_name or (Constants.NAME not in member_detail):
@@ -99,13 +99,13 @@ class JSONConverter(Converter):
                 raise SDKException(code=Constants.EXCEPTION_IS_KEY_MODIFIED, cause=e)
 
             if Constants.REQUIRED in member_detail and member_detail[Constants.REQUIRED]:
-                required_keys.append(key_name)
+                required_keys[key_name] = True
 
             if Constants.REQUIRED_IN_UPDATE in member_detail and member_detail[Constants.REQUIRED_IN_UPDATE]:
-                required_in_update_keys.append(key_name)
+                required_in_update_keys[key_name] = True
 
             if Constants.PRIMARY in member_detail and member_detail[Constants.PRIMARY] and (Constants.REQUIRED_IN_UPDATE not in member_detail or member_detail[Constants.REQUIRED_IN_UPDATE]):
-                primary_keys.append(key_name)
+                primary_keys[key_name] = True
 
             if modification is not None and modification != 0:
                 field_value = getattr(request_instance,
@@ -115,14 +115,9 @@ class JSONConverter(Converter):
                                       value=field_value, unique_values_map=self.unique_dict,
                                       instance_number=instance_number) is True:
                     if field_value is not None:
-                        if key_name in required_keys:
-                            required_keys.remove(key_name)
-
-                        if key_name in primary_keys:
-                            primary_keys.remove(key_name)
-
-                        if key_name in required_in_update_keys:
-                            required_in_update_keys.remove(key_name)
+                        required_keys.pop(key_name, None)
+                        primary_keys.pop(key_name, None)
+                        required_in_update_keys.pop(key_name, None)
 
                     if isinstance(request_instance, FileDetails):
                         if key_name.lower() == Constants.ATTACHMENT_ID.lower():
@@ -141,11 +136,11 @@ class JSONConverter(Converter):
             return request_json
 
     def check_exception(self, member_name, request_instance, instance_number, lookup, required_keys, primary_keys, required_in_update_keys):
-        if len(required_in_update_keys) and self.common_api_handler.get_category_method().upper() == Constants.REQUEST_CATEGORY_UPDATE:
+        if bool(required_in_update_keys) and self.common_api_handler.get_category_method().upper() == Constants.REQUEST_CATEGORY_UPDATE:
             error = {
                 Constants.FIELD: member_name,
                 Constants.TYPE: request_instance.__module__,
-                Constants.KEYS: str(primary_keys)
+                Constants.KEYS: str(list(required_in_update_keys.keys()))
             }
             if instance_number is not None:
                 error[Constants.INSTANCE_NUMBER] = instance_number
@@ -155,33 +150,33 @@ class JSONConverter(Converter):
         if self.common_api_handler.get_mandatory_checker() is not None and self.common_api_handler.get_mandatory_checker():
             if self.common_api_handler.get_category_method().upper() == Constants.REQUEST_CATEGORY_CREATE:
                 if lookup:
-                    if len(primary_keys) > 0:
+                    if bool(primary_keys):
                         error = {
                             Constants.FIELD: member_name,
                             Constants.TYPE: request_instance.__module__,
-                            Constants.KEYS: str(primary_keys)
+                            Constants.KEYS: str(list(primary_keys.keys()))
                         }
                         if instance_number is not None:
                             error[Constants.INSTANCE_NUMBER] = instance_number
 
                         raise SDKException(Constants.MANDATORY_VALUE_ERROR, Constants.MANDATORY_KEY_ERROR, error)
 
-                elif len(required_keys) > 0:
+                elif bool(required_keys):
                     error = {
                         Constants.FIELD: member_name,
                         Constants.TYPE: request_instance.__module__,
-                        Constants.KEYS: str(required_keys)
+                        Constants.KEYS: str(list(required_keys.keys()))
                     }
                     if instance_number is not None:
                         error[Constants.INSTANCE_NUMBER] = instance_number
 
                     raise SDKException(Constants.MANDATORY_VALUE_ERROR, Constants.MANDATORY_KEY_ERROR, error)
 
-            if self.common_api_handler.get_category_method().upper() == Constants.REQUEST_CATEGORY_UPDATE and len(primary_keys) > 0:
+            if self.common_api_handler.get_category_method().upper() == Constants.REQUEST_CATEGORY_UPDATE and bool(primary_keys):
                 error = {
                     Constants.FIELD: member_name,
                     Constants.TYPE: request_instance.__module__,
-                    Constants.KEYS: str(primary_keys)
+                    Constants.KEYS: str(list(primary_keys.keys()))
                 }
                 if instance_number is not None:
                     error[Constants.INSTANCE_NUMBER] = instance_number
@@ -189,11 +184,11 @@ class JSONConverter(Converter):
                 raise SDKException(Constants.MANDATORY_VALUE_ERROR, Constants.PRIMARY_KEY_ERROR, error)
 
         elif lookup and self.common_api_handler.get_category_method().upper() == Constants.REQUEST_CATEGORY_UPDATE:
-            if len(primary_keys) > 0:
+            if bool(primary_keys):
                 error = {
                     Constants.FIELD: member_name,
                     Constants.TYPE: request_instance.__module__,
-                    Constants.KEYS: str(primary_keys)
+                    Constants.KEYS: str(list(primary_keys.keys()))
                 }
                 if instance_number is not None:
                     error[Constants.INSTANCE_NUMBER] = instance_number
@@ -244,28 +239,24 @@ class JSONConverter(Converter):
         key_values = getattr(record_instance, self.construct_private_member(class_name, Constants.KEY_VALUES))
         key_modified = getattr(record_instance, self.construct_private_member(class_name, Constants.KEY_MODIFIED))
 
-        required_keys, primary_keys = [], []
+        required_keys, primary_keys = {}, {}
 
         if not skip_mandatory:
             for key_name, key_detail in module_detail.items():
                 name = key_detail[Constants.NAME]
                 if Constants.REQUIRED in key_detail and key_detail[Constants.REQUIRED]:
-                    if name not in required_keys:
-                        required_keys.append(name)
+                    required_keys[name] = True
 
                 if Constants.PRIMARY in key_detail and key_detail[Constants.PRIMARY]:
-                    if name not in primary_keys:
-                        primary_keys.append(name)
+                    primary_keys[name] = True
 
         for key_name, key_detail in class_detail.items():
             name = key_detail[Constants.NAME]
             if Constants.REQUIRED in key_detail and key_detail[Constants.REQUIRED]:
-                if name not in required_keys:
-                    required_keys.append(name)
+                required_keys[name] = True
 
             if Constants.PRIMARY in key_detail and key_detail[Constants.PRIMARY]:
-                if name not in primary_keys:
-                    primary_keys.append(name)
+                primary_keys[name] = True
 
         for key_name in key_modified.keys():
             if key_modified.get(key_name) != 1:
@@ -277,10 +268,7 @@ class JSONConverter(Converter):
             member_name = self.build_name(key_name)
 
             if len(module_detail) > 0 and (member_name in module_detail or key_name in module_detail):
-                if key_name in module_detail:
-                    key_detail = module_detail[key_name]
-                else:
-                    key_detail = module_detail[member_name]
+                key_detail = module_detail[key_name] if key_name in module_detail else module_detail[member_name]
 
             elif member_name in class_detail:
                 key_detail = class_detail[member_name]
@@ -296,15 +284,12 @@ class JSONConverter(Converter):
                 json_value = self.redirector_for_object_to_json(key_value)
 
             if key_value is not None:
-                if key_name in required_keys:
-                    required_keys.remove(key_name)
-
-                if key_name in primary_keys:
-                    primary_keys.remove(key_name)
+                required_keys.pop(key_name, None)
+                primary_keys.pop(key_name, None)
 
             request_json[key_name] = json_value
 
-        if skip_mandatory or self.check_exception(class_member_name, record_instance, instance_number, lookup, required_keys, primary_keys, []) is True:
+        if skip_mandatory or self.check_exception(class_member_name, record_instance, instance_number, lookup, required_keys, primary_keys, {}) is True:
             return request_json
 
     def set_data(self, member_detail, field_value):
