@@ -190,7 +190,7 @@ class Utility(object):
         subform_modules = []
         fields_json = record_field_details_json[module.lower()]
         for key, value in fields_json.items():
-            if Constants.SUBFORM in value and value[Constants.SUBFORM]:
+            if Constants.SUBFORM in value and value[Constants.SUBFORM] and (value[Constants.MODULE]).lower() in record_field_details_json:
                 subform_modules.append(value[Constants.MODULE])
 
         del record_field_details_json[module.lower()]
@@ -320,7 +320,7 @@ class Utility(object):
         import zcrmsdk.src.com.zoho.crm.api.fields as Field
 
         fields_details = {}
-        response = Field.FieldsOperations(module_api_name).get_fields(None)
+        response = Field.FieldsOperations(module_api_name).get_fields()
 
         if response is not None:
             if response.get_status_code() == Constants.NO_CONTENT_STATUS_CODE:
@@ -511,6 +511,9 @@ class Utility(object):
         if Constants.LOOKUP in api_type.lower():
             field_detail[Constants.LOOKUP] = True
 
+        if api_type.lower() == Constants.CONSENT_LOOKUP:
+            field_detail[Constants.SKIP_MANDATORY] = True
+
         if api_type in Utility.apitype_vs_structurename:
             field_detail[Constants.STRUCTURE_NAME] = Utility.apitype_vs_structurename.get(api_type)
 
