@@ -15,7 +15,7 @@ class VariablesOperations(object):
 		"""Creates an instance of VariablesOperations"""
 		pass
 
-	def get_variables(self, param_instance):
+	def get_variables(self, param_instance=None):
 		"""
 		The method to get variables
 
@@ -35,10 +35,10 @@ class VariablesOperations(object):
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/settings/variables'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
-		handler_instance.param = param_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.response_handler import ResponseHandler
 		except Exception:
@@ -70,12 +70,12 @@ class VariablesOperations(object):
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/settings/variables'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.action_handler import ActionHandler
 		except Exception:
@@ -107,19 +107,19 @@ class VariablesOperations(object):
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/settings/variables'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def delete_variables(self, param_instance):
+	def delete_variables(self, param_instance=None):
 		"""
 		The method to delete variables
 
@@ -139,23 +139,23 @@ class VariablesOperations(object):
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/settings/variables'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.param = param_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def get_variable_by_id(self, param_instance, id):
+	def get_variable_by_id(self, id, param_instance=None):
 		"""
 		The method to get variable by id
 
 		Parameters:
-			param_instance (ParameterMap) : An instance of ParameterMap
 			id (int) : An int representing the id
+			param_instance (ParameterMap) : An instance of ParameterMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -164,33 +164,33 @@ class VariablesOperations(object):
 			SDKException
 		"""
 
-		if param_instance is not None and not isinstance(param_instance, ParameterMap):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
-		
 		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/settings/variables/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
-		handler_instance.param = param_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.response_handler import ResponseHandler
 		except Exception:
 			from .response_handler import ResponseHandler
 		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
 
-	def update_variable_by_id(self, request, id):
+	def update_variable_by_id(self, id, request):
 		"""
 		The method to update variable by id
 
 		Parameters:
-			request (BodyWrapper) : An instance of BodyWrapper
 			id (int) : An int representing the id
+			request (BodyWrapper) : An instance of BodyWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -204,21 +204,21 @@ class VariablesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if request is not None and not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
-		
 		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/settings/variables/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.action_handler import ActionHandler
 		except Exception:
@@ -246,22 +246,22 @@ class VariablesOperations(object):
 		api_path = ''
 		api_path = api_path + '/crm/v2/settings/variables/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def get_variable_for_api_name(self, param_instance, api_name):
+	def get_variable_for_api_name(self, api_name, param_instance=None):
 		"""
 		The method to get variable for api name
 
 		Parameters:
-			param_instance (ParameterMap) : An instance of ParameterMap
 			api_name (string) : A string representing the api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -270,33 +270,33 @@ class VariablesOperations(object):
 			SDKException
 		"""
 
-		if param_instance is not None and not isinstance(param_instance, ParameterMap):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
-		
 		if not isinstance(api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: api_name EXPECTED TYPE: str', None, None)
 		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/settings/variables/'
 		api_path = api_path + str(api_name)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
-		handler_instance.param = param_instance
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.response_handler import ResponseHandler
 		except Exception:
 			from .response_handler import ResponseHandler
 		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
 
-	def update_variable_by_api_name(self, request, api_name):
+	def update_variable_by_api_name(self, api_name, request):
 		"""
 		The method to update variable by api name
 
 		Parameters:
-			request (BodyWrapper) : An instance of BodyWrapper
 			api_name (string) : A string representing the api_name
+			request (BodyWrapper) : An instance of BodyWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -310,21 +310,21 @@ class VariablesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if request is not None and not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
-		
 		if not isinstance(api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: api_name EXPECTED TYPE: str', None, None)
 		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/settings/variables/'
 		api_path = api_path + str(api_name)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.action_handler import ActionHandler
 		except Exception:
